//! Core algorithms and data structures.

pub mod check_out;
pub mod config;
pub mod dag;
pub mod effects;
pub mod eventlog;
pub mod formatting;
pub mod gc;
pub mod node_descriptors;
pub mod repo_ext;
pub mod rewrite;
pub mod task;
